@@ -73,8 +73,8 @@ export BAR='foo'`,
 				"echo 'Goodbye, World!'",
 				" echo \"with space\"",
 				"export BAR='foo'",
-				"echo setvar FOO=${FOO}",
-				"echo setvar BAR=${BAR}",
+				"echo \"setvar FOO:SQ=${FOO}\"",
+				"echo \"setvar BAR:SQ=${BAR}\"",
 			},
 		},
 		{
@@ -97,8 +97,8 @@ export FOO='bar'
 				"export BAR",
 				"export FOO='bar'",
 				"  export BAZ='qux'",
-				"echo setvar FOO=${FOO}",
-				"echo setvar BAZ=${BAZ}",
+				"echo \"setvar FOO:SQ=${FOO}\"",
+				"echo \"setvar BAZ:SQ=${BAZ}\"",
 			},
 		},
 		{
@@ -121,7 +121,7 @@ export FOO='bar'`,
 				"echo 'Goodbye, World!'",
 				"export BAR",
 				"export FOO='bar'",
-				"echo setvar FOO=${FOO}",
+				"echo \"setvar FOO:SQ=${FOO}\"",
 			},
 		},
 		{
@@ -144,7 +144,7 @@ export FOO='bar'`,
 				"echo 'Goodbye, World!'",
 				"export BAR",
 				"export FOO='bar'",
-				"echo setvar FOO=${FOO}",
+				"echo \"setvar FOO:SQ=${FOO}\"",
 			},
 		},
 		{
@@ -214,7 +214,7 @@ echo 'Goodbye, World!'`,
 				"#!/bin/sh",
 				"set -e",
 				"export GREETING='Hello, World!'",
-				"echo setvar GREETING=${GREETING}",
+				"echo \"setvar GREETING:SQ=${GREETING}\"",
 			},
 		},
 		{
