@@ -163,7 +163,7 @@ func TestPlaybook_New(t *testing.T) {
 	})
 
 	t.Run("playbook with secrets", func(t *testing.T) {
-		secProvider := &mocks.SecretProvider{
+		secProvider := &mocks.SecretsProviderMock{
 			GetFunc: func(key string) (string, error) {
 				switch key {
 				case "SEC1":
@@ -198,7 +198,7 @@ func TestPlaybook_New(t *testing.T) {
 	})
 
 	t.Run("playbook with options", func(t *testing.T) {
-		secProvider := &mocks.SecretProvider{
+		secProvider := &mocks.SecretsProviderMock{
 			GetFunc: func(key string) (string, error) {
 				switch key {
 				case "SEC1":
@@ -342,8 +342,9 @@ func TestTargetHosts(t *testing.T) {
 			"target3": {Name: "target3", Groups: []string{"group1"},
 				Hosts: []Destination{{Host: "host4.example.com", Port: 22, Name: "host4", Tags: []string{"tag4"}, User: "user4"}},
 			},
-			"target4": {Name: "target4", Groups: []string{"group1"}, Names: []string{"host3"}},
-			"target5": {Name: "target5", Tags: []string{"tag1"}},
+			"target4":      {Name: "target4", Groups: []string{"group1"}, Names: []string{"host3"}},
+			"target5":      {Name: "target5", Tags: []string{"tag1"}},
+			"target-empty": {Name: "target-empty", Groups: []string{"empty-group", "gpu-nodes"}},
 		},
 		inventory: &InventoryData{
 			Groups: map[string][]Destination{
@@ -356,6 +357,8 @@ func TestTargetHosts(t *testing.T) {
 				"group1": {
 					{Host: "host2.example.com", Port: 2222, User: "defaultuser", Name: "host2", Tags: []string{"tag1"}},
 				},
+				"empty-group": {}, // empty group
+				"gpu-nodes":   {}, // empty group
 			},
 			Hosts: []Destination{
 				{Host: "host3.example.com", Port: 22, Name: "host3", Tags: []string{"tag1", "tag2"}},
@@ -458,6 +461,16 @@ func TestTargetHosts(t *testing.T) {
 			[]Destination{{Host: "host3.example.com", Port: 22, User: "overriddenuser", Name: "host3", Tags: []string{"tag1", "tag2"}}},
 			false,
 		},
+		{
+			"empty group direct targeting", "empty-group", nil,
+			nil, // returns nil, no error
+			false,
+		},
+		{
+			"target with only empty groups", "target-empty", nil,
+			nil,
+			true, // should error when no hosts found
+		},
 	}
 
 	for _, tc := range testCases {
@@ -752,7 +765,7 @@ func TestPlayBook_checkConfig(t *testing.T) {
 
 func TestPlayBook_loadSecrets(t *testing.T) {
 	// mock secret provider
-	secProvider := mocks.SecretProvider{
+	secProvider := mocks.SecretsProviderMock{
 		GetFunc: func(key string) (string, error) {
 			if key == "secret1" {
 				return "value1", nil
